==> haskell-doctemplates-0.1.0.2-16-i686.pkg.tar.xz: usr/share/haskell/register/haskell-doctemplates.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: doctemplates
version: 0.1.0.2
id: doctemplates-0.1.0.2-JGjuL5UnGBmE4TPeZqA9xK
key: doctemplates-0.1.0.2-JGjuL5UnGBmE4TPeZqA9xK
license: BSD3
copyright: 2016 John MacFarlane
maintainer: jgm@berkeley.edu
homepage: https://github.com/jgm/doctemplates#readme
synopsis: Pandoc-style document templates
description:
    Please see README.md
category: Text
author: John MacFarlane
exposed: True
exposed-modules:
    Text.DocTemplates
abi: 544e5a39c014483d08b4d87e55f5ab68
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/doctemplates-0.1.0.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/doctemplates-0.1.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/doctemplates-0.1.0.2
hs-libraries: HSdoctemplates-0.1.0.2-JGjuL5UnGBmE4TPeZqA9xK
depends:
    aeson-1.1.2.0-H03krkO26IxG3qbwGKHggZ base-4.9.0.0
    blaze-html-0.8.1.3-J9yr8vH3H9ALelvCpTjDjF
    blaze-markup-0.7.1.1-JmLydCOPoKfKgaFgoOctdP bytestring-0.10.8.1
    containers-0.5.7.1 parsec-3.1.11-IYEP8Lv1S9x5FeUQxGPDBY
    scientific-0.3.4.12-HGDD5CZlHOuAviiRjYU5iD
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    unordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
    vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
haddock-interfaces: /usr/share/doc/haskell-doctemplates/html/doctemplates.haddock
haddock-html: /usr/share/doc/haskell-doctemplates/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-doctemplates-0.1.0.2-17-i686.pkg.tar.xz: usr/share/haskell/register/haskell-doctemplates.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: doctemplates
version: 0.1.0.2
id: doctemplates-0.1.0.2-JByiLimuwwj6QapxYvoOf3
key: doctemplates-0.1.0.2-JByiLimuwwj6QapxYvoOf3
license: BSD3
copyright: 2016 John MacFarlane
maintainer: jgm@berkeley.edu
homepage: https://github.com/jgm/doctemplates#readme
synopsis: Pandoc-style document templates
description:
    Please see README.md
category: Text
author: John MacFarlane
exposed: True
exposed-modules:
    Text.DocTemplates
abi: 5ec6f27d470c2154888caed50286cb25
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/doctemplates-0.1.0.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/doctemplates-0.1.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/doctemplates-0.1.0.2
hs-libraries: HSdoctemplates-0.1.0.2-JByiLimuwwj6QapxYvoOf3
depends:
    aeson-1.1.2.0-KSzOWeOw6cI7ymVovOXtxy base-4.9.0.0
    blaze-html-0.8.1.3-5umpHbJSFbGGX5TQ5mnIPt
    blaze-markup-0.7.1.1-VJaDzmYXPW8F1IHSBweDX bytestring-0.10.8.1
    containers-0.5.7.1 parsec-3.1.11-LsiSww7OPVN4zZBDwUQHXr
    scientific-0.3.4.12-JvEgWsdvKgxFZH5v4yXqI3
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v
    unordered-containers-0.2.8.0-Njz6QHP7Gk5G9PhT6D28J
    vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
haddock-interfaces: /usr/share/doc/haskell-doctemplates/html/doctemplates.haddock
haddock-html: /usr/share/doc/haskell-doctemplates/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
